Class: Libvirt::FFI::Error::Struct
- Inherits:
-
FFI::Struct
- Object
- FFI::Struct
- Libvirt::FFI::Error::Struct
- Defined in:
- lib/libvirt/ffi/error.rb
Overview
struct virError { int code # The error code, a virErrorNumber int domain # What part of the library raised this error char * message # human-readable informative error message virErrorLevel level # how consequent is the error virConnectPtr conn # connection if available, deprecated see note above virDomainPtr dom # domain if available, deprecated see note above char * str1 # extra string information char * str2 # extra string information char * str3 # extra string information int int1 # extra number information int int2 # extra number information virNetworkPtr net # network if available, deprecated see note above }